package edu.umd.dawn.common.services;

import org.springframework.stereotype.Service;

import edu.umd.dawn.common.models.UserAgent.UserAgentBuilder;
import nl.basjes.parse.useragent.UserAgent;
import nl.basjes.parse.useragent.UserAgentAnalyzer;

import static nl.basjes.parse.useragent.classify.DeviceClass.TABLET;
import static nl.basjes.parse.useragent.classify.DeviceClass.PHONE;;

@Service
public class UserAgentService {
    private UserAgentAnalyzer uaa = UserAgentAnalyzer
    .newBuilder()
    .hideMatcherLoadStats()
    .withCache(10000)
    .build();

    private UserAgentBuilder setDeviceType(UserAgent ua, UserAgentBuilder builder) {
        String deviceType = ua.get(UserAgent.DEVICE_CLASS).getValue().toLowerCase();
        if (deviceType.equals(TABLET.getValue().toLowerCase())) {
            builder.tablet(true);
        } else if (deviceType.equals(PHONE.getValue().toLowerCase())) {
            builder.mobile(true);
        } else if (deviceType.startsWith("robot")) {
            builder.bot(true);
        } else {
            builder.desktop(true);
        }
        return builder;
    }

    public edu.umd.dawn.common.models.UserAgent parse(String userAgenString) {
        UserAgent ua = uaa.parse(userAgenString);

        UserAgentBuilder builder = edu.umd.dawn.common.models.UserAgent.builder();
        builder = setDeviceType(ua, builder);
        builder.device(ua.get(UserAgent.DEVICE_NAME).getValue());


        return builder.build();
    }
}
